"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const express = require("express");
const uuid_1 = require("uuid");
const script_1 = require("./script");
const puppeteer = require("puppeteer");
const serviceConfig = require('./config.json');
const app = express();
app.get('/', (req, res) => {
    const uuid = uuid_1.v4();
    console.log(`${script_1.getTimeStamp()} ${uuid} pdf job received`);
    console.log(`${script_1.getTimeStamp()} ${uuid} ${JSON.stringify(req.query)}`);
    const margin = {
        bottom: req.query.marginBottom || '0px',
        left: req.query.marginLeft || '0px',
        right: req.query.marginRight || '0px',
        top: req.query.marginTop || '0px'
    };
    const format = req.query.format ? req.query.format.toLowerCase() : undefined;
    const printConfig = {
        format: format,
        landscape: req.query.landscape === 'true' ? true : false,
        height: req.query.height,
        width: req.query.width,
        margin,
        url: req.query.url,
        windowStatus: req.query.windowStatus,
        uuid,
        deviceScaleFactor: req.query.deviceScaleFactor,
        useBodyHeight: req.query.useBodyHeight === 'true' ? true : false
    };
    if (req.query.image === 'true') {
        script_1.makePng(printConfig, serviceConfig).then(buffer => {
            console.log(`${script_1.getTimeStamp()} ${uuid} png job done`);
            if (buffer) {
                if (req.query.addAttachementHeader === 'true') {
                    res.writeHead(200, {
                        'Content-Type': 'image/png',
                        'Content-Disposition': `attachment; filename=${uuid}.png`,
                        'Content-Length': buffer.length
                    });
                }
                else {
                    res.writeHead(200, {
                        'Content-Type': 'image/png',
                        'Content-Length': buffer.length
                    });
                }
                res.end(buffer);
            }
        }).catch(error => {
            console.log(`${script_1.getTimeStamp()} ${uuid} png job error: ${error.message}`);
            res.status(500).send(error.message);
        });
    }
    else {
        script_1.makePdf(printConfig, serviceConfig).then(buffer => {
            console.log(`${script_1.getTimeStamp()} ${uuid} pdf job done`);
            if (req.query.addAttachementHeader === 'true') {
                res.writeHead(200, {
                    'Content-Type': 'application/pdf',
                    'Content-Disposition': `attachment; filename=${uuid}.pdf`,
                    'Content-Length': buffer.length
                });
            }
            else {
                res.writeHead(200, {
                    'Content-Type': 'application/pdf',
                    'Content-Length': buffer.length
                });
            }
            res.end(buffer);
        }).catch(error => {
            console.log(`${script_1.getTimeStamp()} ${uuid} pdf job error: ${error.message}`);
            res.status(500).send(error.message);
        });
    }
});
app.listen(serviceConfig.port);
// log startup config
console.log('--------------------------------------------------------------------');
console.log(`${script_1.getTimeStamp()} pdf service started on port ${serviceConfig.port}`);
console.log(`${script_1.getTimeStamp()} navigation timeout: ${serviceConfig.navigationTimeout}ms`);
console.log(`${script_1.getTimeStamp()} windows status timeout: ${serviceConfig.windowsStatusTimeout}ms`);
console.log(`${script_1.getTimeStamp()} print on windows status timeout: ${serviceConfig.printOnWindowsStatusTimeout}`);
console.log(`${script_1.getTimeStamp()} ignore HTTPS errors: ${serviceConfig.ignoreHTTPSErrors}`);
console.log(`${script_1.getTimeStamp()} ChromeHeadless arguments: ${serviceConfig.args || 'none'}`);
if (serviceConfig.referer) {
    console.log(`${script_1.getTimeStamp()} referer override: ${serviceConfig.referer}`);
}
puppeteer.launch().then(browser => {
    browser.version().then(version => {
        console.log(`${script_1.getTimeStamp()} ChromeHeadless version: ${version}`);
        browser.userAgent().then(ua => {
            console.log(`${script_1.getTimeStamp()} user agent: ${ua}`);
            if (serviceConfig.userAgent) {
                console.log(`${script_1.getTimeStamp()} user agent override: ${serviceConfig.userAgent}`);
            }
            browser.close();
            console.log('--------------------------------------------------------------------');
        });
    });
});
