"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTimeStamp = exports.makePng = exports.makePdf = void 0;
const puppeteer = require("puppeteer");
function makePdf(options, serviceConfig) {
    return __awaiter(this, void 0, void 0, function* () {
        const { page, browser } = yield preparePage(serviceConfig, options);
        const pdfConfig = {
            printBackground: true,
            landscape: options.landscape ? true : false,
            format: options.width && options.height ? undefined : options.format,
            width: options.width,
            height: options.height,
            margin: options.margin
        };
        console.log(`${getTimeStamp()} ${options.uuid} make pdf with config: ${JSON.stringify(pdfConfig)}`);
        const buffer = yield page.pdf(pdfConfig);
        browser.close();
        return buffer;
    });
}
exports.makePdf = makePdf;
function makePng(options, serviceConfig) {
    return __awaiter(this, void 0, void 0, function* () {
        const { page, browser } = yield preparePage(serviceConfig, options);
        if (options.useBodyHeight) {
            const bodyHeight = yield page.evaluate(() => {
                return document.getElementsByTagName('body')[0].clientHeight;
            });
            options.height = bodyHeight.toString();
        }
        const screenshotClip = {
            x: 0,
            y: 0,
            width: options.width ? parseFloat(options.width) : 0,
            height: options.height ? parseFloat(options.height) : 0
        };
        const screenshotConfig = {
            type: 'png',
            fullPage: options.width && options.height ? false : true,
            clip: options.width && options.height ? screenshotClip : undefined,
            omitBackground: true,
            encoding: 'binary'
        };
        const viewPortConfig = {
            height: screenshotClip.height,
            width: screenshotClip.width,
            deviceScaleFactor: options.deviceScaleFactor ? parseFloat(options.deviceScaleFactor) : 1
        };
        page.setViewport(viewPortConfig);
        console.log(`${getTimeStamp()} ${options.uuid} make png with screenshot config: ${JSON.stringify(screenshotConfig)}, and viewport config ${JSON.stringify(viewPortConfig)}`);
        const buffer = yield page.screenshot(screenshotConfig); // assume binary encoding
        browser.close();
        return buffer;
    });
}
exports.makePng = makePng;
function preparePage(serviceConfig, options) {
    return __awaiter(this, void 0, void 0, function* () {
        let browser;
        let args;
        if (serviceConfig.args) {
            args = serviceConfig.args;
        }
        try {
            browser = yield puppeteer.launch({
                ignoreHTTPSErrors: serviceConfig.ignoreHTTPSErrors,
                args
            });
        }
        catch (ex) {
            console.error(ex);
            throw ex;
        }
        const page = yield browser.newPage();
        if (serviceConfig.userAgent) {
            page.setUserAgent(serviceConfig.userAgent);
        }
        try {
            console.log(`${getTimeStamp()} ${options.uuid} open page '${options.url}' ...`);
            const result = yield page.goto(options.url, {
                referer: serviceConfig.referer || undefined,
                timeout: serviceConfig.navigationTimeout
            });
            if (!result) {
                browser.close();
                throw new Error(`page result is null`);
            }
            const status = result.status();
            if (status !== 200) {
                browser.close();
                throw new Error(`cannot open page: http status code is ${status}`);
            }
            console.log(`${getTimeStamp()} ${options.uuid} page loaded`);
        }
        catch (ex) {
            console.error(ex);
            browser.close();
            throw ex;
        }
        if (options.windowStatus) {
            console.log(`${getTimeStamp()} ${options.uuid} wait for window.status === '${options.windowStatus}'`);
            let readyForPdf = false;
            let time = 0;
            while (!readyForPdf && time < serviceConfig.windowsStatusTimeout) {
                yield wait(100);
                time += 100;
                readyForPdf = yield page.evaluate((windowStatus) => {
                    return window.status === windowStatus;
                }, options.windowStatus);
            }
            if (!readyForPdf && !serviceConfig.printOnWindowsStatusTimeout) {
                browser.close();
                throw new Error(`timeout - window.status is not ok after ${serviceConfig.windowsStatusTimeout}ms`);
            }
            else if (!readyForPdf && serviceConfig.printOnWindowsStatusTimeout) {
                console.log(`${getTimeStamp()} ${options.uuid} window.status not ok, but continue`);
            }
            else {
                console.log(`${getTimeStamp()} ${options.uuid} window.status is ok`);
            }
        }
        return { page, browser };
    });
}
function wait(ms) {
    return new Promise(resolve => setTimeout(resolve, ms));
}
function getTimeStamp() {
    const date = new Date();
    return `${date.toLocaleDateString()} ${date.toLocaleTimeString()} `;
}
exports.getTimeStamp = getTimeStamp;
