"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const script_1 = require("./script");
const chai_1 = require("chai");
describe('makePdf function', () => {
    it('should return pdf file if format is passed', () => __awaiter(void 0, void 0, void 0, function* () {
        const margin = {
            bottom: '0px',
            left: '0px',
            right: '0px',
            top: '0px'
        };
        const config = {
            format: 'a4',
            landscape: true,
            height: undefined,
            width: undefined,
            margin,
            url: 'https://www.google.ch',
            windowStatus: undefined,
            uuid: 'test',
            deviceScaleFactor: '1',
            useBodyHeight: false
        };
        const servcieConfig = {
            port: 3000,
            windowsStatusTimeout: 60000,
            navigationTimeout: 30000,
            ignoreHTTPSErrors: false,
            printOnWindowsStatusTimeout: false
        };
        const testPromise = script_1.makePdf(config, servcieConfig);
        const buffer = yield testPromise;
        chai_1.expect(buffer.length).to.greaterThan(0);
    }));
    it('should return pdf file if width and height are passed', () => __awaiter(void 0, void 0, void 0, function* () {
        const margin = {
            bottom: '0px',
            left: '0px',
            right: '0px',
            top: '0px'
        };
        const config = {
            format: undefined,
            landscape: true,
            height: '500px',
            width: '500px',
            margin,
            url: 'https://www.google.ch',
            windowStatus: undefined,
            uuid: 'test',
            deviceScaleFactor: '1',
            useBodyHeight: false
        };
        const servcieConfig = {
            port: 3000,
            windowsStatusTimeout: 60000,
            navigationTimeout: 30000,
            ignoreHTTPSErrors: false,
            printOnWindowsStatusTimeout: false
        };
        const testPromise = script_1.makePdf(config, servcieConfig);
        const buffer = yield testPromise;
        chai_1.expect(buffer.length).to.greaterThan(0);
    }));
    it('should return timeout error', () => __awaiter(void 0, void 0, void 0, function* () {
        const margin = {
            bottom: '0px',
            left: '0px',
            right: '0px',
            top: '0px'
        };
        const config = {
            format: 'a4',
            landscape: true,
            height: undefined,
            width: undefined,
            margin,
            url: 'https://www.google.ch',
            windowStatus: 'testStatus',
            uuid: 'test',
            deviceScaleFactor: '1',
            useBodyHeight: false
        };
        const servcieConfig = {
            port: 3000,
            windowsStatusTimeout: 1000,
            navigationTimeout: 30000,
            ignoreHTTPSErrors: false,
            printOnWindowsStatusTimeout: false
        };
        try {
            const testPromise = script_1.makePdf(config, servcieConfig);
            yield testPromise;
        }
        catch (ex) {
            console.log(ex);
            chai_1.expect(ex.message).to.equal('timeout - window.status is not ok after 1000ms');
        }
    }));
});
describe('makePng function', () => {
    it('should return png file if format is passed', () => __awaiter(void 0, void 0, void 0, function* () {
        const margin = {
            bottom: '0px',
            left: '0px',
            right: '0px',
            top: '0px'
        };
        const config = {
            format: 'a4',
            landscape: true,
            height: undefined,
            width: undefined,
            margin,
            url: 'https://www.google.ch',
            windowStatus: undefined,
            uuid: 'test',
            deviceScaleFactor: '1',
            useBodyHeight: false
        };
        const servcieConfig = {
            port: 3000,
            windowsStatusTimeout: 60000,
            navigationTimeout: 30000,
            ignoreHTTPSErrors: false,
            printOnWindowsStatusTimeout: false
        };
        const testPromise = script_1.makePng(config, servcieConfig);
        const buffer = yield testPromise;
        chai_1.expect(buffer === null || buffer === void 0 ? void 0 : buffer.length).to.greaterThan(0);
    }));
    it('should return png file if width and height are passed', () => __awaiter(void 0, void 0, void 0, function* () {
        const margin = {
            bottom: '0px',
            left: '0px',
            right: '0px',
            top: '0px'
        };
        const config = {
            format: undefined,
            landscape: true,
            height: '500px',
            width: '500px',
            margin,
            url: 'https://www.google.ch',
            windowStatus: undefined,
            uuid: 'test',
            deviceScaleFactor: '1',
            useBodyHeight: false
        };
        const servcieConfig = {
            port: 3000,
            windowsStatusTimeout: 60000,
            navigationTimeout: 30000,
            ignoreHTTPSErrors: false,
            printOnWindowsStatusTimeout: false
        };
        const testPromise = script_1.makePng(config, servcieConfig);
        const buffer = yield testPromise;
        chai_1.expect(buffer === null || buffer === void 0 ? void 0 : buffer.length).to.greaterThan(0);
    }));
    it('should return larger png file if deviceScaleFactor is set', () => __awaiter(void 0, void 0, void 0, function* () {
        const margin = {
            bottom: '0px',
            left: '0px',
            right: '0px',
            top: '0px'
        };
        const config = {
            format: undefined,
            landscape: true,
            height: '500px',
            width: '500px',
            margin,
            url: 'https://www.google.ch',
            windowStatus: undefined,
            uuid: 'test',
            deviceScaleFactor: '1',
            useBodyHeight: false
        };
        const servcieConfig = {
            port: 3000,
            windowsStatusTimeout: 60000,
            navigationTimeout: 30000,
            ignoreHTTPSErrors: false,
            printOnWindowsStatusTimeout: false
        };
        const testPromise = script_1.makePng(config, servcieConfig);
        const buffer = yield testPromise;
        chai_1.expect(buffer === null || buffer === void 0 ? void 0 : buffer.length).to.greaterThan(0);
        config.deviceScaleFactor = '2';
        const testPromise2 = script_1.makePng(config, servcieConfig);
        const buffer2 = yield testPromise2;
        chai_1.expect(buffer2 === null || buffer2 === void 0 ? void 0 : buffer2.length).to.greaterThan(0);
        chai_1.expect(buffer2 === null || buffer2 === void 0 ? void 0 : buffer2.length).to.greaterThan((buffer === null || buffer === void 0 ? void 0 : buffer.length) || 0);
    }));
    it('should print body height', () => __awaiter(void 0, void 0, void 0, function* () {
        const margin = {
            bottom: '0px',
            left: '0px',
            right: '0px',
            top: '0px'
        };
        const config = {
            format: undefined,
            landscape: true,
            height: '500px',
            width: '500px',
            margin,
            url: 'https://www.google.ch',
            windowStatus: undefined,
            uuid: 'test',
            deviceScaleFactor: '1',
            useBodyHeight: false
        };
        const servcieConfig = {
            port: 3000,
            windowsStatusTimeout: 60000,
            navigationTimeout: 30000,
            ignoreHTTPSErrors: false,
            printOnWindowsStatusTimeout: false
        };
        const testPromise = script_1.makePng(config, servcieConfig);
        const buffer = yield testPromise;
        chai_1.expect(buffer === null || buffer === void 0 ? void 0 : buffer.length).to.greaterThan(0);
        config.useBodyHeight = true;
        const testPromise2 = script_1.makePng(config, servcieConfig);
        const buffer2 = yield testPromise2;
        chai_1.expect(buffer2 === null || buffer2 === void 0 ? void 0 : buffer2.length).to.greaterThan(0);
        chai_1.expect(buffer2 === null || buffer2 === void 0 ? void 0 : buffer2.length).to.greaterThan((buffer === null || buffer === void 0 ? void 0 : buffer.length) || 0);
    }));
});
